@@ -96,6 +96,7 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-rar",                  ".rar",      0 },
 	{ "application/x-rpm",                  ".rpm",      0 },
 	{ "application/x-rzip",                 ".rz",       0 },
+	{ "application/x-rzip-compressed-tar",  ".tar.rz",   0 },
 	{ "application/x-tar",                  ".tar",      0 },
 	{ "application/x-tarz",                 ".tar.Z",    0 },
 	{ "application/x-stuffit",              ".sit",      0 },
@@ -147,6 +148,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".tar.lzma", "application/x-lzma-compressed-tar" },
 	{ ".tar.lzo", "application/x-lzop-compressed-tar" },
 	{ ".tar.7z", "application/x-7z-compressed-tar" },
+	{ ".tar.rz", "application/x-rzip-compressed-tar" },
 	{ ".tar.xz", "application/x-xz-compressed-tar" },
 	{ ".tar.Z", "application/x-tarz" },
 	{ ".taz", "application/x-tarz" },
