@@ -19,6 +19,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <config.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <stdio.h>
@@ -812,9 +813,19 @@ check_child (gpointer data)
 		}
 	}
 
-	if (info->ignore_error) {
+	if (info->ignore_error && (exec_data->error != NULL)) {
+#ifdef DEBUG
+			{
+				GList *scan;
+
+				g_print ("** ERROR **\n");
+				g_print ("%s\n", exec_data->error->gerror->message);
+				for (scan = process->err.raw; scan; scan = scan->next)
+					g_print ("%s\n", (char *)scan->data);
+			}
+#endif
 		fr_clear_error (&exec_data->error);
-		debug (DEBUG_INFO, "[ignore error]\n");
+		debug (DEBUG_INFO, "[error ignored]\n");
 	}
 	else if (exec_data->error == NULL) {
 		if (WIFEXITED (status)) {
@@ -961,6 +972,9 @@ execute_current_command (ExecuteData *exec_data)
 		if (info->dir != NULL)
 			g_print ("\tcd %s\n", info->dir);
 
+		if (info->ignore_error)
+			g_print ("\t[ignore error]\n");
+
 		g_print ("\t");
 		for (j = 0; j < i; j++)
 			g_print ("%s ", argv[j]);
