@@ -106,6 +106,11 @@ struct _FrWindowClass
 GType           fr_window_get_type                     (void);
 GtkWidget *     fr_window_new                          (void);
 void            fr_window_close                        (FrWindow      *window);
+void            fr_window_set_dialog		       (FrWindow      *window,
+							const char    *dialog_name,
+							GtkWidget     *dialog);
+gboolean        fr_window_present_dialog_if_created    (FrWindow      *window,
+							const char    *dialog_name);
 
 /* archive operations */
 
