@@ -923,6 +923,12 @@ _g_path_remove_level (const gchar *path)
 	if (p < 0)
 		return NULL;
 
+	/* ignore the first slash if it's the last character,
+	 * this way /a/b/ is treated as /a/b */
+
+	if ((ptr[p] == '/') && (p > 0))
+		p--;
+
 	while ((p > 0) && (ptr[p] != '/'))
 		p--;
 	if ((p == 0) && (ptr[p] == '/'))
